import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_DragAndDropToOffset(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_DragAndDropToOffset")

    def execute(self, sourceSelector, targetXOffset, targetYOffset):
        if sourceSelector is None:
            raise Exception("sourceSelector is required")
        if targetXOffset is None:
            raise Exception("targetXOffset is required")
        if targetYOffset is None:
            raise Exception("targetYOffset is required")

        requestObj = [sourceSelector, targetXOffset, targetYOffset]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_DragAndDropToOffset was successful", "MultiAction_DragAndDropToOffset failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class StartWebDriver(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.StartWebDriver")

    def execute(self, browser, serverUrl):
        requestObj = []
        if browser is not None:
            requestObj = [browser]
            if serverUrl is not None:
                requestObj = [browser, serverUrl]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "StartWebDriver was successful", "StartWebDriver failed")



from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class SwitchToNewWindowCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.SwitchToNewWindow")

    def execute(self, windowName, url):
        if windowName is None:
            raise Exception("window name is required")

        requestObj = [windowName]
        if url is not None:
            requestObj = [windowName, url]
            
        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "SwitchToNewWindow was successful", "SwitchToNewWindow failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class WaitForControl(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.WaitForControl")

    def execute(self, selector, seconds):
        if selector is None:
            raise Exception("selector is required")
        if seconds is None:
            raise Exception("seconds is required")

        requestObj = [selector, seconds]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "WaitForControl was successful", "WaitForControl failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class SwitchToWindow(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.SwitchToWindow")

    def execute(self, windowName):
        if windowName is None:
            raise Exception("window name is required")

        requestObj = [windowName]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "SwitchToWindow was successful", "SwitchToWindow failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_New(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_New")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_New was successful", "MultiAction_New failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class ScrollBy(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.ScrollBy")

    def execute(self, x, y):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")

        requestObj = [x, y]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "ScrollBy was successful", "ScrollBy failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_Release(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_Release")

    def execute(self, selector):
        if selector is None:
            requestObj = []
        else:
            requestObj = [selector]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_Release was successful", "MultiAction_Release failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class SendKeysAlert(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.SendKeysAlert")

    def execute(self, text):
        if text is None:
            raise Exception("text is required")

        requestObj = [text]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "SendKeysAlert was successful", "SendKeysAlert failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetCurrentWindowHandleResult import GetCurrentWindowHandleResult


class GetCurrentWindowHandle(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.GetCurrentWindowHandle")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetCurrentWindowHandleResult(result, "GetCurrentWindowHandle was successful", "GetCurrentWindowHandle failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MaximizeWindow(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MaximizeWindow")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MaximizeWindow was successful", "MaximizeWindow failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class AddChromeExtension(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.AddChromeExtension")

    def execute(self, filepath):
        if filepath is None:
            raise Exception("filepath is required")

        requestObj = [filepath]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "AddChromeExtension was successful", "AddChromeExtension failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class AddCapabilityCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.AddCapability")

    def execute(self, key, value):
        if key is None:
            raise Exception("key is required")
        if value is None:
            raise Exception("value is required")

        requestObj = [key, value]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "AddCapability was successful", "AddCapability failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_SendKeys(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_Sendkeys")

    def execute(self, inputString, selector):
        if inputString is None:
            raise Exception("inputString is required")

        requestObj = [inputString]
        if selector is not None:
            requestObj = [selector, inputString]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_SendKeys was successful", "MultiAction_SendKeys failed")



from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class CloseWindowCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.CloseWindow")

    def execute(self, windowName):
        requestObj = []
        
        if windowName is not None:
            requestObj = [windowName]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "CloseWindow was successful", "CloseWindow failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetWindowHandlesResult import GetWindowHandlesResult


class GetWindowHandles(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.GetWindowHandles")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetWindowHandlesResult(result, "GetWindowHandles was successful", "GetWindowHandles failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class AddArgumentCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.AddArgument")

    def execute(self, argument):
        if argument is None:
            raise Exception("argument is required")

        requestObj = [argument]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "AddArgument was successful", "AddArgument failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetChildrenResult import GetChildrenResult


class GetChildren(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.GetChildren")

    def execute(self, selector):
        if selector is None:
            raise Exception("selector is required")

        requestObj = [selector]

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetChildrenResult(result, "GetChildren was successful", "GetChildren failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_keyUp(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_KeyUp")

    def execute(self, key, selector):
        if key is None:
            raise Exception("key is required")

        requestObj = [key]
        if selector is not None:
            requestObj = [selector, key]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_keyUp was successful", "MultiAction_keyUp failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetElementAttributeResult import GetElementAttributeResult


class GetElementAttribute(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.GetElementAttribute")

    def execute(self, selector, name):
        if selector is None:
            raise Exception("selector is required")
        if name is None:
            raise Exception("name is required")

        requestObj = [selector, name]

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetElementAttributeResult(result, "GetElementAttribute was successful", "GetElementAttribute failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class GoToUrl(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.GoToUrl")

    def execute(self, url):
        if url is None:
            raise Exception("url is required")

        requestObj = [url]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "GoToUrl was successful", "GoToUrl failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class AuthenticateUrl(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.AuthenticateUrl")

    def execute(self, username, password, link):
        if username is None:
            raise Exception("username is required")
        if password is None:
            raise Exception("password is required")
        if link is None:
            raise Exception("link is required")

        requestObj = [username, password, link]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "AuthenticateUrl was successful", "AuthenticateUrl failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult


class MultiAction_DragAndDrop(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Selenium.MultiAction_DragAndDrop")

    def execute(self, sourceSelector, targetSelector):
        if sourceSelector is None:
            raise Exception("sourceSelector is required")
        if targetSelector is None:
            raise Exception("targetSelector is required")

        requestObj = [sourceSelector, targetSelector]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkErrorCodeAndMessageResult(result, "MultiAction_DragAndDrop was successful", "MultiAction_DragAndDrop failed")
